template_gen
------------

.. currentmodule:: eqcorrscan.core.template_gen
.. automodule:: eqcorrscan.core.template_gen

Routines for cutting waveforms around picks for use as
templates for matched filtering.

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       template_gen
       extract_from_stack

    .. comment to end block
